# -*- coding:utf-8 -*-
from __future__ import absolute_import, unicode_literals, print_function

class DBManage:
    def __init__(self, filename):
        pass

    def select(self, keyword):
        pass

    def update(self, keyword):
        return False

    def insert(self, keyword, data):
        return False

    def delete(self, keyword):
        return False



# -*- coding:utf-8 -*-
from __future__ import absolute_import, unicode_literals, print_function
import sys
from argparse import ArgumentParser
from termcolor import colored
from .Spider import Spider

class Manager:
    def __init__(self):
        self.args = {'word': None}
        self.data = {}

    def search(self, args):
        spi = Spider(**args)
        spi.search()
        self.data = spi.result
        return self.data

    def args_parse(self):
        args_parser = DoctorArguments()
        if len(sys.argv) < 2:
            args_parser.print_help()
            sys.exit(0)
        self.args = vars(args_parser.parse_args())
        return self.args

    def print(self):
        pr = PrintManager(self.data)
        pr.print()

    def work(self):
        self.args_parse()
        self.search(self.args)
        self.print()

class DoctorArguments(ArgumentParser):
    def __init__(self, *args, **kwargs):
        super(DoctorArguments, self).__init__(*args, **kwargs)
        self.add_argument('keyword', metavar='Words', type=str)
        self.description = 'Doctor: help you a better English'
        self.prog = 'Doctor'


print_basic = lambda x: {v:colored(k, 'green') for v, k in x.items() if v !='explains'}
print_basic_explains = lambda x: '\n'.join(['{}. {}'.format(i, colored(s, 'blue')) for i,s in enumerate(x, 1)])
print_web = lambda x: '\n'.join(['{i}{key}: {value}'.format(i=i, key=s['key'], value=colored(', '.join(s['value']), 'green')) for i,s in enumerate(x, 1)])
class PrintManager:
    print_module = {
        'query': [lambda x: '词: {}'.format(colored(x, 'green')), 1],
        'translation': [lambda x: '翻译: {}'.format(', '.join([colored(y, 'blue') for y in x])), 2],
        'basic': [lambda x: '英: [{uk-phonetic}] 美: [{us-phonetic}] 英标: [{phonetic}]\n解释:\n{explains}'.format(explains=print_basic_explains(x['explains']), **(print_basic(x))), 3],
        'web': [lambda x: '其他意思:\n{web}'.format(web=print_web(x)), 4]
    }
    def __init__(self, data):
        self.data = data

    def print(self):
        print_data = []
        for v in self.data:
            if v in self.print_module:
                print_data.append((self.print_module[v][1], self.print_module[v][0](self.data[v])))
        print_data.sort()
        for i, p in print_data:
            print(p.encode('utf-8'))


# -*- coding:utf-8 -*-
from __future__ import absolute_import, unicode_literals, print_function
from setuptools import setup, find_packages

setup(
    name='dictman',
    version='0.1.3',
    description='a English word shell finder',
    author='zhanglun',
    author_email='zhanglun.me@gmail.com',
    packages=['dictman'],
    install_requires=['termcolor'],
    entry_points={
        'console_scripts':[
            'dictman = dictman.main:main'
        ]
    }

)


# -*- coding:utf-8 -*-
from __future__ import absolute_import, unicode_literals, print_function
import json
import requests
from .DBManagers import DBManage


class Spider:
    youdao_api = 'http://fanyi.youdao.com/openapi.do?keyfrom={keyfrom}&key={key}&type=data&doctype=json&version=1.1&q={keyword}'

    def __init__(self, keyword, filename='', keyfrom='EnglishSearcher', key='1098649915'):
        self.keyword = keyword
        self.content = None
        self.db = DBManage(filename)
        self.keyfrom = keyfrom
        self.key = key

    def search(self):
        url = self.youdao_api.format(keyfrom=self.keyfrom, key=self.key, keyword=self.keyword)
        response = requests.get(url)
        self.content = response.json()

    def find(self):
        self.db.select(self.keyword)
        self.content = 'find'

    @property
    def result(self):
        self.find()
        self.search()
        return self.content
